# Check the Chain Documentation

## Contents
- [Main Overview](/README.md): main README with introduction and install information
- [Configuration](/docs/config.md): overview of `ctc` configuration
- [Codebase Tour](/docs/code_tour.md): overview of `ctc` code conventions and organization
- [Command Line Interface](/docs/cli): overview of `ctc` cli
- [Examples](/docs/examples): examples of `ctc` usage

